@@ -39,6 +39,7 @@
   *)
 
 (** {2 Exceptions} *)
+
 (** An error occured. In the future, this exception should be replaced by more
   * specific exceptions. Use [string_of_error] to get a description of the
   * error. *)
@@ -72,15 +73,14 @@ val terminate : unit -> unit
 (** {2 Host API} *)
 
 (** Host API Information *)
-type host_api_info =
-    {
-        h_struct_version : int;
-        h_host_api_type : int;
-        h_name : string;
-        h_device_count : int;
-        h_default_input_device : int;
-        h_default_output_device : int
-    }
+type host_api_info = {
+  h_struct_version : int;
+  h_host_api_type : int;
+  h_name : string;
+  h_device_count : int;
+  h_default_input_device : int;
+  h_default_output_device : int;
+}
 
 (** Number of available host API. *)
 val get_host_api_count : unit -> int
@@ -92,19 +92,18 @@ val get_default_host_api : unit -> int
 val get_host_api_info : int -> host_api_info
 
 (** Device Information *)
-type device_info =
-    {
-        d_struct_version : int;
-        d_name : string;
-        d_host_api : int;
-        d_max_input_channels : int;
-        d_max_output_channels : int;
-        d_default_low_input_latency : float;
-        d_default_low_output_latency : float;
-        d_default_high_input_latency : float;
-        d_default_high_output_latency : float;
-        d_default_sample_rate : float
-    }
+type device_info = {
+  d_struct_version : int;
+  d_name : string;
+  d_host_api : int;
+  d_max_input_channels : int;
+  d_max_output_channels : int;
+  d_default_low_input_latency : float;
+  d_default_low_output_latency : float;
+  d_default_high_input_latency : float;
+  d_default_high_output_latency : float;
+  d_default_sample_rate : float;
+}
 
 (** Default input device. *)
 val get_default_input_device : unit -> int
@@ -120,9 +119,10 @@ val get_device_info : int -> device_info
 
 (** {2 Streams} *)
 
-(**   The abstract type [('a, 'b) sample_format] describes the OCaml type ['a]
- * and the underlying C type ['a] used to represent the data being written to or
- * read from a stream.  This type is compatible with [('a, 'b) Bigarray.kind]. *)
+(** The abstract type [('a, 'b) sample_format] describes the OCaml type ['a] and
+    the underlying C type ['b] used to represent the data being written to or
+    read from a stream.  This type is compatible with [('a, 'b)
+    Bigarray.kind]. *)
 type ('a, 'b) sample_format
 
 (** See {!Portaudio.format_float32}. *)
@@ -141,21 +141,23 @@ val format_int32 : (int32, Bigarray.int32_elt) sample_format
  * The underlying type is a 32 bit float. *)
 val format_float32 : (float, Bigarray.float32_elt) sample_format
 
-type ('a, 'b) stream_parameters =
-    {
-      channels : int;
-      device : int;
-      sample_format : ('a, 'b) sample_format;
-      latency : float;
-    }
+type ('a, 'b) stream_parameters = {
+  channels : int;
+  device : int;
+  sample_format : ('a, 'b) sample_format;
+  latency : float;
+}
 
 type stream_flag
-
 type ('a, 'b, 'c, 'd) stream
 
 (** The function signature of a callback.  Callbacks only work with interleaved
- * streams. *)
-type ('a, 'b, 'c, 'd) callback = ('a, 'b, Bigarray.c_layout) Bigarray.Genarray.t -> ('c, 'd, Bigarray.c_layout) Bigarray.Genarray.t -> int -> int
+   streams. *)
+type ('a, 'b, 'c, 'd) callback =
+  ('a, 'b, Bigarray.c_layout) Bigarray.Genarray.t ->
+  ('c, 'd, Bigarray.c_layout) Bigarray.Genarray.t ->
+  int ->
+  int
 
 (** [open_stream inparam outparam interleaved rate bufframes callback flags] opens a new
   * stream with input stream of format [inparam], output stream of format
@@ -163,16 +165,30 @@ type ('a, 'b, 'c, 'd) callback = ('a, 'b, Bigarray.c_layout) Bigarray.Genarray.t
   * at [rate] samples per second, with [bufframes] frames per buffer
   * passed the callback function [callback] (0 means leave this choice to
   * portaudio). *)
-val open_stream : ('a, 'b) stream_parameters option -> ('c, 'd) stream_parameters option -> ?interleaved:bool ->
-    float -> int -> ?callback:(('a, 'b, 'c, 'd) callback) -> stream_flag list -> ('a, 'b, 'c, 'd) stream
+val open_stream :
+  ('a, 'b) stream_parameters option ->
+  ('c, 'd) stream_parameters option ->
+  ?interleaved:bool ->
+  float ->
+  int ->
+  ?callback:('a, 'b, 'c, 'd) callback ->
+  stream_flag list ->
+  ('a, 'b, 'c, 'd) stream
 
 (** [open_default_stream callback format interleaved inchans outchans rate bufframes]
- * opens default stream with [callback] as callback function, handling samples in
+  * opens default stream with [callback] as callback function, handling samples in
   * [format] format using interleaved or non-interleaved buffers [interleaved] with
   * [inchans] input channels and [outchans] output channels
   * at [rate] samples per seconds with handling buffers of size [bufframes]. *)
-val open_default_stream : ?callback:(('a, 'b, 'a, 'b) callback) -> ?format:(('a, 'b) sample_format) ->
-    ?interleaved:bool -> int -> int -> int -> int -> ('a, 'b, 'a, 'b) stream
+val open_default_stream :
+  ?callback:('a, 'b, 'a, 'b) callback ->
+  ?format:('a, 'b) sample_format ->
+  ?interleaved:bool ->
+  int ->
+  int ->
+  int ->
+  int ->
+  ('a, 'b, 'a, 'b) stream
 
 (** Close a stream. *)
 val close_stream : ('a, 'b, 'c, 'd) stream -> unit
@@ -190,13 +206,25 @@ val abort_stream : ('a, 'b, 'c, 'd) stream -> unit
 val sleep : int -> unit
 
 (** Write to a stream. *)
-val write_stream : ('a, 'b, 'c, 'd) stream -> 'c array array -> int -> int -> unit
+val write_stream :
+  ('a, 'b, 'c, 'd) stream -> 'c array array -> int -> int -> unit
 
 (** Read from a stream. *)
-val read_stream : ('a, 'b, 'c, 'd) stream -> 'a array array -> int -> int -> unit
+val read_stream :
+  ('a, 'b, 'c, 'd) stream -> 'a array array -> int -> int -> unit
 
 (** Write to a stream using a bigarray. *)
-val write_stream_ba : ('a, 'b, 'c, 'd) stream -> ('c, 'd, Bigarray.c_layout) Bigarray.Genarray.t -> int -> int -> unit
+val write_stream_ba :
+  ('a, 'b, 'c, 'd) stream ->
+  ('c, 'd, Bigarray.c_layout) Bigarray.Genarray.t ->
+  int ->
+  int ->
+  unit
 
 (** Read from a stream using a bigarray. *)
-val read_stream_ba : ('a, 'b, 'c, 'd) stream -> ('a, 'b, Bigarray.c_layout) Bigarray.Genarray.t -> int -> int -> unit
+val read_stream_ba :
+  ('a, 'b, 'c, 'd) stream ->
+  ('a, 'b, Bigarray.c_layout) Bigarray.Genarray.t ->
+  int ->
+  int ->
+  unit
